OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Napačno geslo",
    "The new password can not be the same as the previous one" : "Novo geslo ne sme biti enako prejšnjemu.",
    "No user supplied" : "Ni navedenega uporabnika",
    "Authentication error" : "Napaka med overjanjem",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški podatki izgubljeni.",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Ozadnji program ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniško šifriranje.",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "%s password changed successfully" : "Geslo (%s) je uspešno spremenjeno",
    "Couldn't send reset email. Please contact your administrator." : "Ni mogoče poslati elektronskega naslova za ponastavitev. Stopite v stik s skrbnikom sistema.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "Program cURL uporablja zastarelo različico %s (%s). Posodobite operacijski sistem, sicer zmožnosti, kot je %s, ne bodo delovale zanesljivo.",
    "A problem occurred, please check your log files (Error: %s)" : "Prišlo je do napake. Preverite dnevniške zapise (napaka: %s).",
    "Migration Completed" : "Selitev je končana",
    "Group already exists." : "Skupina že obstaja.",
    "Unable to add group." : "Ni mogoče dodati skupine",
    "Unable to delete group." : "Ni mogoče izbrisati skupine.",
    "log-level out of allowed range" : "stopnja zapisovanja je izven dovoljenega območja",
    "Saved" : "Shranjeno",
    "test email settings" : "preizkusi nastavitve elektronske pošte",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "Email sent" : "Elektronska pošta je poslana",
    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
    "Couldn't change the email address because the user does not exist" : "Elektronskega naslova ni mogoče spremeniti, ker uporabnik s tem naslovom ne obstaja",
    "Couldn't change the email address because the token is invalid" : "Ni mogoče spremeniti naslova elektronske pošte, ker je žeton neveljaven.",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "A user with that name already exists." : "Uporabnik s tem imenom že obstaja.",
    "Unable to create user." : "Ni mogoče ustvariti uporabnika.",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Unable to delete user." : "Ni mogoče izbrisati uporabnika",
    "Forbidden" : "Dostop je prepovedan",
    "Invalid user" : "Neveljavni podatki uporabnika",
    "Unable to change mail address" : "Ni mogoče spremeniti naslova elektronske pošte.",
    "Email has been changed successfully." : "Elektronski naslov je uspešno spremenjen.",
    "Your full name has been changed." : "Vaše polno ime je spremenjeno.",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "Unable to enable/disable user." : "Ni mogoče omogočiti/onemogočiti dostopa uporabnika.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Slovenščina",
    "Language changed" : "Jezik je spremenjen",
    "Invalid request" : "Neveljavna zahteva",
    "Admins can't remove themself from the admin group" : "Skrbnikov ni mogoče odstraniti iz skupine skrbnikov (admin)",
    "Unknown user" : "Neznan uporabnik",
    "Couldn't remove app." : "Ni mogoče odstraniti programa.",
    "Official" : "Uradno",
    "Approved" : "Odobreno",
    "All" : "Vsi",
    "Enabled" : "Omogočeno",
    "Not enabled" : "Ni omogočeno",
    "No apps found for your version" : "Za to različico ni na voljo noben vstavek",
    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Uradno odobrene programe razvija skupnost ownCloud. Ti omogočajo osnovne zmožnosti v oblaku in so vedno posodobljeni za uporabo.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Potrjeno programsko opremo razvijajo zaupanja vredni razvijalci, ki so tudi varnostno preverjeni. Koda je neprestano pod nadzorom v skladišču odprte kode, razvijalci pa skrbijo, da je delovanje programa stabilno.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ta program ni varnostno preverjen, saj je nov oziroma še nestabilna različica. Namestitev je na vašo odgovornost.",
    "Please wait...." : "Počakajte ...",
    "Error while disabling app" : "Napaka onemogočanja programa",
    "Disable" : "Onemogoči",
    "Enable" : "Omogoči",
    "Error while enabling app" : "Napaka omogočanja programa",
    "Error: this app cannot be enabled because it makes the server unstable" : "Napaka: programa ni mogoče omogočiti, ker povzroča nestabilnost strežnika",
    "Error: could not disable broken app" : "Napaka: ni mogoče onemogočiti okvarjenega programa",
    "Error while disabling broken app" : "Napaka onemogočanja okvarjenega programa",
    "Updating...." : "Poteka posodabljanje ...",
    "Error while updating app" : "Prišlo je do napake med posodabljanjem programa.",
    "Updated" : "Posodobljeno",
    "Uninstalling ...." : "Odstranjevanje namestitve ...",
    "Error while uninstalling app" : "Prišlo je do napake med odstranjevanjem programa.",
    "Uninstall" : "Odstrani namestitev",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Vstavek je omogočen, vendar zahteva posodobitev. Samodejno bo izvedena preusmeritev na stran za posodobitev v 5 sekundah.",
    "App update" : "Posodabljanje vstavkov",
    "Experimental" : "Preizkusno",
    "No apps found for {query}" : "Ni programov, skladnih z nizom \"{query}\".",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ali ste prepričani, da želite dodati \"{domain}\" kot varno domeno?",
    "Add trusted domain" : "Dodaj varno domeno",
    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
    "Migration started …" : "Selitev je začeta ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
    "Valid until {date}" : "Veljavno do {date}",
    "Delete" : "Izbriši",
    "Disconnect" : "Prekinjeni povezavo",
    "Error while loading browser sessions and device tokens" : "Prišlo je d napake med nalaganjem seje brskalnika in žetonov naprave",
    "Error while creating device token" : "Napaka med ustvarjanjem žetonov naprave",
    "Error while deleting the token" : "Napaka med brisanjem žetona",
    "Sending..." : "Poteka pošiljanje ...",
    "Failed to change the email address." : "Spreminjanje naslova elektronske pošte je spodletelo.",
    "Email changed successfully." : "Elektronski naslov je uspešno spremenjen.",
    "An error occurred: {message}" : "Prišlo je do napake: {message}",
    "Select a profile picture" : "Izbor slike profila",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Groups" : "Skupine",
    "Unable to delete {objName}" : "Ni mogoče izbrisati {objName}",
    "Error creating group: {message}" : "Napaka ustvarjanja skupine: {message}",
    "A valid group name must be provided" : "Navedeno mora biti veljavno ime skupine",
    "deleted {groupName}" : "izbrisano {groupName}",
    "undo" : "razveljavi",
    "never" : "nikoli",
    "deleted {userName}" : "izbrisano {userName}",
    "add group" : "dodaj skupino",
    "Invalid quota value \"{val}\"" : "Neveljavna vrednost količinske omejitve \"{val}\"",
    "enabled" : "omogočeno",
    "disabled" : "onemogočeno",
    "no group" : "ni skupine",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Sprememba gesla bo povzročila izgubo podatkov, ker obnova podatkov za tega uporabnika ni na voljo.",
    "Password successfully changed" : "Geslo je uspešno spremenjeno.",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Error creating user: {message}" : "Napaka ustvarjanja uporabnika: {message}",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "A valid email must be provided" : "Naveden mora biti veljaven naslov elektronske pošte.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Pozdravljeni,<br><br>obveščamo vas, da je račun %s pripravljen.<br><br>Uporabniško ime: %s<br>Dostop: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Lep pozdrav!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Pozdravljeni,\n\nobveščamo vas, da je račun %s pripravljen.\n\nUporabniško ime: %s\nDostop: %s\n",
    "User documentation" : "Uporabniška dokumentacija",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "Online documentation" : "Spletna dokumentacija",
    "Forum" : "Forum",
    "Issue tracker" : "Sledilnih zahtevkov",
    "Commercial support" : "Podpora strankam",
    "Apps Management" : "Upravljanje programov",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "by %s" : "-- %s",
    "%s-licensed" : "dovoljenje-%s",
    "Documentation:" : "Dokumentacija:",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Visit website" : "Obiščite spletno stran",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "Show description …" : "Pokaži opis ...",
    "Hide description …" : "Skrij opis ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Program nima določene najstarejše podprte različice oblaka ownCloud. Tovrstne napake javljajo različice ownCloud 11 in novejše.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Program nima določene najnovejše podprte različice oblaka ownCloud. Tovrstne napake javljajo različice ownCloud 11 in novejše.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
    "Enable only for specific groups" : "Omogoči le za posamezne skupine",
    "Uninstall App" : "Odstrani program",
    "Show enabled apps" : "Pokaži omogočene programe",
    "Show disabled apps" : "Pokaži onemogočene programe",
    "Cron" : "Periodično opravilo",
    "Last cron job execution: %s." : "Zadnje izvedeno periodično opravilo: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Zadnje izvedeno periodično opravilo: %s. Videti je, da je nekaj narobe.",
    "Cron was not executed yet!" : "Periodično opravilo cron še ni zagnano!",
    "Open documentation" : "Odprta dokumentacija",
    "Execute one task with each page loaded" : "Izvedi eno nalogo z vsako naloženo stranjo.",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Datoteka cron.php je vpisana za periodično opravilo webcron za potrditev sklica vsakih 15 minut pri povezavi prek HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Uporabi storitev periodičnih opravil za klic datoteke cron.php vsakih 15 minut.",
    "SSL Root Certificates" : "Korenska potrdila SSL",
    "Common Name" : "Splošno ime",
    "Valid until" : "Veljavno do",
    "Issued By" : "Izdajatelj",
    "Valid until %s" : "Veljavno do %s",
    "Import root certificate" : "Uvozi korensko potrdilo",
    "Server-side encryption" : "Šifriranje na strežniku",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "Please read carefully before activating server-side encryption: " : "Pozorno preberite opombe, preden omogočite strežniško šifriranje:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ko je šifriranje enkrat omogočeno, bodo vse datoteke, ki bodo na novo poslane na strežnik, šifrirane. Po tem bo šifriranje mogoče onemogočiti le z nameščenim modulom, ki tovrstno šifriranje podpira, in z izpolnjenimi vsemi nastavljenimi pogoji (na primer nastavitev obnovitvenega ključa).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Samo šifriranje še ni dovolj za zagotavljanje varnosti sistema. Za več podrobnosti o delovanju programa za šifriranje in podprtih načinih uporabe si oglejte dokumentacijo ownCloud.",
    "Be aware that encryption always increases the file size." : "Upoštevajte, da so šifriranje datoteke vedno obsežnejše od nešifriranih.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vedno je priporočeno redno pripravljati varnostne kopije podatkov. Za šifrirane datoteke je treba narediti varnostno kopijo tudi šifrirnih ključen.",
    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
    "Enable encryption" : "Omogoči šifriranje",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ni naloženega modula za šifriranje. Omogočiti ga je mogoče v meniju programa.",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega. Omogočite »Privzeti šifrirni modul» in zaženite ukaz 'occ encryption:migrate', ali pa stopite v stik s skrbnikom sistema.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Prenesti je treba šifrirne ključe iz stare šifrirne sheme (ownCloud ≤ 8.0) na novo.",
    "Start migration" : "Začni selitev",
    "Sharing" : "Souporaba",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Set default expiration date" : "Vsili nastavitev privzetega datuma poteka",
    "Allow users to send mail notification for shared files" : "Dovoli uporabnikom pošiljati obvestila o souporabi datotek po elektronski pošti",
    "Allow users to share file via social media" : "Uporabnikom dovoli objavljanje datotek prek socialnih omrežij",
    "Expire after " : "Preteče po",
    "days" : "dneh",
    "Enforce expiration date" : "Vsili datum preteka",
    "Allow resharing" : "Dovoli nadaljnjo souporabo",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Allow users to send mail notification for shared files to other users" : "Dovoli uporabnikom pošiljanje obvestil o souporabi datotek tudi drugim uporabnikom",
    "Exclude groups from sharing" : "Izloči skupine iz souporabe",
    "These groups will still be able to receive shares, but not to initiate them." : "Te skupine lahko sprejemajo mape v souporabo, ne morejo pa souporabe dovoliti",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Dovoli samodejno dokončanje uporabniškega imena pri dodeljevanju datotek ali map v souporabo. Če je možnost onemogočena, je treba vpisati celotno uporabniško ime.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Vse (podrobnosti, opozorila, hrošče, napake in usodni dogodki)",
    "Info, warnings, errors and fatal issues" : "Podrobnosti, opozorila, napake in usodni dogodki",
    "Warnings, errors and fatal issues" : "Opozorila, napake in usodni dogodki",
    "Errors and fatal issues" : "Napake in usodni dogodki",
    "Fatal issues only" : "Le usodni dogodki",
    "Log" : "Dnevnik",
    "What to log" : "Kaj naj se beleži?",
    "Download logfile (%s)" : "Dnevnik prejemov (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Dnevniškega datoteka je večja od 100 MB. Hitrost prejema je odvisna od širokopasovne povezave!",
    "None" : "Brez",
    "Login" : "Prijava",
    "Plain" : "Besedilno",
    "NT LAN Manager" : "Upravljalnik NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Poštni strežnik",
    "This is used for sending out notifications." : "Možnost je uporabljena za omogočanje pošiljanja obvestil.",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "From address" : "Naslov pošiljatelja",
    "mail" : "pošta",
    "Authentication method" : "Način overitve",
    "Authentication required" : "Zahtevana je overitev",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Credentials" : "Poverila",
    "SMTP Username" : "Uporabniško ime SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Store credentials" : "Shrani poverila",
    "Test email settings" : "Preizkus nastavitev elektronske pošte",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "kaže, da se v okolju php poizvedba sistemskih okoljskih spremenljivk ne nastavi pravilno. Preizkus z ukazom getenv(\"PATH\") vrne le prazen odziv.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Preverite <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacijo namestitve ↗</a> za opombe k nastavitvam php in nastavitve strežnika; še posebej, kadar je v uporabi php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogočene so nastavitve »le za branje«. To onemogoča nastavljanje možnosti prek spletnega vmesnika, problem pa se lahko pojavi pri posodobitvah, saj je treba datoteko vsakič ročno omogočiti.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Nastavitve PHP določajo, da so medvrstični bloki besedila odrezani. Ta nastavitev lahko povzroči, da nekateri osnovni moduli ne bodo dosegljivi.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilniški program ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Podatkovna zbirka ni zagnana na ravni izolacije transakcij »READ COMMITED« (branje izvedeno). To lahko povzroči težave, če je vzporedno izvedenih več dejanj.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "Nameščena je različica programa %1$s, ki je nižja od %2$s. Za zagotavljanje stabilnosti sistema ter hitrosti in odzivnosti delovanja je priporočljivo program %1$s posodobiti.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Manjka modul PHP 'fileinfo'. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Zaklepanje prenosljivih datotek je onemogočeno, kar lahko vpliva na vrsto napak. Zaklepanje je priporočljivo omogočiti s parametrom 'filelocking.enabled' v nastavitveni datoteki config.php. Več podrobnosti je navedenih v <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">doumentaciji ↗</a>.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Zaklepanje prenosljivih datotek mora biti nastavljeno za uporabo zaklepanja na osnovi pomnilnika in ne na privzeto zaklepanje podatkovne zbirke. Več podrobnosti je navedenih v <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">doumentaciji ↗</a>.",
    "System locale can not be set to a one which supports UTF-8." : "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
    "This means that there might be problems with certain characters in file names." : "To pomeni, da se lahko pojavijo napake pri nekaterih znakih v imenih datotek.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Priporočljivo je namestiti zahtevane pakete v sistem za podporo ene izmed navedenih jezikovnih možnosti: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Če sistem ni nameščen v korensko mapo domene, uporablja pa okolje cron, se lahko pojavijo težave z ustvarjanjem naslovov URL. V nastavitveno datoteko config.php je priporočljivo vpisati možnost »overwrite.cli.url« s potjo v koren namestitve spletišča (priporočilo: »%s«).",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Uporabljena zbirka je SQLite. Za obsežnejše sisteme je priporočljiv prehod na drugo vrsto zbirke.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, to še posebej velja, če se sistem krajevno usklajuje z namizjem prek odjemalca.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Za prehod na drug sistem podatkovne zbirje uporabite ukazno vrstico: 'occ db:convert-type' ali pa si oglejte možnosti, zabeležene v <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaciji ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Priporočljivo je omogočiti sistemsko okolje cron, saj drugi načini lahko vplivajo na hitrost in zanesljivost delovanja.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Ni mogoče izvesti ukaza cronjpob prek ukazne vrstice CLI. Prišlo je do tehničnih napak:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Priporočljivo je preučiti dokumentacijo <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Vodnika namestitve ↗</a> in preveriti morebitne napake in opozorila, zabeležena v <a href=\"#log-section\">dnevniku</a>.",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "System Status" : "Stanje sistema",
    "Tips & tricks" : "Nasveti in triki",
    "How to do backups" : "Kako ustvariti varnostne kopije",
    "Advanced monitoring" : "Napredno sledenje",
    "Performance tuning" : "Prilagajanje delovanja",
    "Improving the config.php" : "Izboljšave v config.php",
    "Theming" : "Teme",
    "Hardening and security guidance" : "Varnost in varnostni napotki",
    "Get the apps to sync your files" : "Pridobi programe za usklajevanje datotek",
    "Desktop client" : "Namizni odjemalec",
    "Android app" : "Program za Android",
    "iOS app" : "Program za iOS",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Če želite podpreti projekt\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">se pridružite razvijalcem</a>,\n\t\t\tali pa le \n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">razširite dober glas</a>!",
    "Show First Run Wizard again" : "Zaženi čarovnika prvega zagona",
    "Profile picture" : "Slika profila",
    "Upload new" : "Pošlji novo",
    "Select from Files" : "Izbor iz datotek",
    "Remove image" : "Odstrani sliko",
    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
    "Picture provided by original account" : "Slika iz izvornega računa",
    "Cancel" : "Prekliči",
    "Choose as profile picture" : "Izberi kot sliko profila",
    "Full name" : "Polno ime",
    "No display name set" : "Prikazno ime ni nastavljeno",
    "Email" : "Elektronski naslov",
    "Your email address" : "Osebni elektronski naslov",
    "Change email" : "Spremeni naslov elektronske pošte",
    "Set email" : "Spremeni naslov elektronske pošte",
    "For password recovery and notifications" : "Za obnovo gesla in obveščanje",
    "No email address set" : "Poštni naslov ni nastavljen",
    "You are member of the following groups:" : "Ste član naslednjih skupin:",
    "Password" : "Geslo",
    "Unable to change your password" : "Gesla ni mogoče spremeniti.",
    "Current password" : "Trenutno geslo",
    "New password" : "Novo geslo",
    "Change password" : "Spremeni geslo",
    "Language" : "Jezik",
    "Help translate" : "Sodelujte pri prevajanju",
    "Unlimited" : "Neomejeno",
    "You are using %s of %s" : "Uporabljate %s od %s",
    "You are using %s of %s (%s %%)" : "Uporabljate %s od %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Programski paket razvija {communityopen}skupnost ownCloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena z dovoljenjem {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Seje",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Spodaj so navedeni spletni brskalniki in programi na mobilnih napravah, ki so trenutno povezani z oblakom ownCloud.",
    "Browser" : "Brskalnik",
    "Most recent activity" : "Zadnja dejavnost",
    "App passwords" : "Gesla programa",
    "You've linked these apps." : "Povezali ste povezali te programe.",
    "Name" : "Ime",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Programsko geslo je koda PIN, s katero se program lahko poveže v račun %s.",
    "App name" : "Naziv programa",
    "Create new app password" : "Ustvari novo geslo programa",
    "Use the credentials below to configure your app or device." : "Uporabite spodaj navedena poverila za nastavitev programa ali naprave.",
    "Username" : "Uporabniško ime",
    "Done" : "Končano",
    "Version" : "Različica",
    "Personal" : "Osebno",
    "Admin" : "Skrbništvo",
    "Error" : "Napaka",
    "Show enabled/disabled option" : "Pokaži možnost omogoči/onemogoči",
    "Show storage location" : "Pokaži mesto shrambe",
    "Show last log in" : "Pokaži podatke zadnje prijave",
    "Show user backend" : "Pokaži ozadnji program",
    "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
    "Show email address" : "Pokaži naslov elektronske pošte",
    "E-Mail" : "Elektronska pošta",
    "Create" : "Ustvari",
    "Admin Recovery Password" : "Obnovitev skrbniškega gesla",
    "Enter the recovery password in order to recover the users files during password change" : "Vnesite geslo, ki omogoča obnovitev uporabniških datotek med spreminjanjem gesla",
    "Add Group" : "Dodaj skupino",
    "Group" : "Skupina",
    "Everyone" : "Vsi",
    "Admins" : "Skrbniki",
    "Default Quota" : "Privzeta količinska omejitev",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Vnesite količinsko omejitev prostora (na primer: \"512 MB\" ali \"12 GB\")",
    "Other" : "Drugo",
    "Full Name" : "Polno ime",
    "Group Admin for" : "Skrbnik skupine za",
    "Quota" : "Količinska omejitev",
    "Storage Location" : "Mesto shrambe",
    "User Backend" : "Uporabniški ozadnji program",
    "Last Login" : "Zadnja prijava",
    "change full name" : "Spremeni polno ime",
    "set new password" : "nastavi novo geslo",
    "change email address" : "spremeni naslov elektronske pošte",
    "Default" : "Privzeto",
    "Share" : "Souporaba",
    "Domain" : "Domena",
    "Add" : "Dodaj"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
